@@ -88,13 +88,8 @@ working hour in `casual-timezone-planner'."
   :type 'string
   :group 'casual)
 
-(defcustom casual-timezone-zone-info-database
-  (file-name-concat (or (getenv "TZDIR") "/usr/share/zoneinfo")
-                    "tzdata.zi")
-  "Path to the tzdata.zi file used by `casual-timezone-zone-info'.
-
-Defaults to $TZDIR/tzdata.zi when the TZDIR environment variable
-is set and /usr/share/zoneinfo/tzdata.zi otherwise."
+(defcustom casual-timezone-zone-info-database "/usr/share/zoneinfo/tzdata.zi"
+  "Path to the tzdata.zi file used by `casual-timezone-zone-info'."
   :type 'file
   :group 'casual)
 
